@@ -112,15 +112,15 @@ class Transcription(models.Model):
         patterns = []
         for i in range(len(phones)):
             patt = phones[:i] #Substitutions
-            patt.append(any_segment)
-            patt.extend(phones[i+1:])
+            patt += any_segment
+            patt += phones[i+1:]
             patterns.append('^'+''.join(patt) +'$')
             patt = phones[:i] #Deletions
-            patt.extend(phones[i+1:])
+            patt += phones[i+1:]
             patterns.append('^'+''.join(patt) +'$')
             patt = phones[:i] #Insertions
-            patt.append(any_segment)
-            patt.extend(phones[i:])
+            patt += any_segment
+            patt += phones[i:]
             patterns.append('^'+''.join(patt) +'$')
 
         neighs = Transcription.objects.extra(
