@@ -64,7 +64,7 @@ def lookupSpelling(orth):
     except IndexError:
         return None
     words = [x.word_form for x in o.spelledas_set.all()]
-    word = max(words,key=lambda x: (x.get_cond_prob_of_spelling(o)*x.get_probability)/o.get_probability())
+    word = max(words,key=lambda x: (x.get_cond_prob_of_spelling(o)*x.get_probability())/o.get_probability())
     return word
 
 # P(W|s) = P(s|W) * p(W)/P(s)
